import { ITerminal } from '@rushstack/node-core-library';
import { NewlineKind } from '@rushstack/node-core-library';
import { StringValuesTypingsGenerator } from '@rushstack/typings-generator';

/**
 * Get a function that pseudolocalizes a string.
 *
 * @public
 */
export declare function getPseudolocalizer(options: IPseudolocaleOptions): (str: string) => string;

/**
 * @public
 */
export declare interface ILocalizationFile {
    [stringName: string]: ILocalizedString;
}

/**
 * @public
 */
export declare interface ILocalizedString {
    value: string;
    comment?: string;
}

/**
 * @public
 */
export declare interface IParseFileOptions {
    content: string;
    filePath: string;
}

/**
 * @public
 */
export declare interface IParseLocFileOptions {
    terminal: ITerminal;
    filePath: string;
    content: string;
    parser?: ParserKind;
    resxNewlineNormalization: NewlineKind | undefined;
    ignoreMissingResxComments: boolean | undefined;
}

/**
 * Options for the pseudolocale library.
 *
 * @internalRemarks
 * Eventually this should be replaced with DefinitelyTyped types.
 *
 * @public
 */
export declare interface IPseudolocaleOptions {
    prepend?: string;
    append?: string;
    delimiter?: string;
    startDelimiter?: string;
    endDelimiter?: string;
    extend?: number;
    override?: string;
}

/**
 * @public
 */
export declare interface IResxReaderOptions {
    resxFilePath: string;
    terminal: ITerminal;
    newlineNormalization: NewlineKind | undefined;
    warnOnMissingComment: boolean;
}

/**
 * @public
 */
export declare interface ITypingsGeneratorOptions {
    srcFolder: string;
    generatedTsFolder: string;
    terminal?: ITerminal;
    exportAsDefault?: boolean;
    globsToIgnore?: string[];
    resxNewlineNormalization?: NewlineKind | undefined;
    ignoreMissingResxComments?: boolean | undefined;
    ignoreString?: (resxFilePath: string, stringName: string) => boolean;
    processComment?: (comment: string | undefined, resxFilePath: string, stringName: string) => string | undefined;
}

/**
 * @public
 */
export declare function parseLocFile(options: IParseLocFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare function parseLocJson(options: IParseFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare function parseResJson(options: IParseFileOptions): ILocalizationFile;

/**
 * @public
 */
export declare type ParserKind = 'resx' | 'loc.json' | 'resjson';

/**
 * @public
 */
export declare function readResxAsLocFile(resxContents: string, options: IResxReaderOptions): ILocalizationFile;

/**
 * @public
 */
export declare function readResxFileAsLocFile(options: IResxReaderOptions): ILocalizationFile;

/**
 * This is a simple tool that generates .d.ts files for .loc.json, .resx.json, .resjson, and .resx files.
 *
 * @public
 */
export declare class TypingsGenerator extends StringValuesTypingsGenerator {
    constructor(options: ITypingsGeneratorOptions);
}

export { }
