"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseLocFile = exports.selectParserByFilePath = void 0;
const parseLocJson_1 = require("./parsers/parseLocJson");
const parseResJson_1 = require("./parsers/parseResJson");
const ResxReader_1 = require("./ResxReader");
const parseCache = new Map();
function selectParserByFilePath(filePath) {
    if (/\.resx$/i.test(filePath)) {
        return 'resx';
    }
    else if (/\.(resx|loc)\.json$/i.test(filePath)) {
        return 'loc.json';
    }
    else if (/\.resjson$/i.test(filePath)) {
        return 'resjson';
    }
    else {
        throw new Error(`Unsupported file extension in file: ${filePath}`);
    }
}
exports.selectParserByFilePath = selectParserByFilePath;
/**
 * @public
 */
function parseLocFile(options) {
    const { parser = selectParserByFilePath(options.filePath) } = options;
    let parsedFile;
    if (parser === 'resx') {
        const fileCacheKey = `${options.filePath}?${options.resxNewlineNormalization || 'none'}`;
        if (parseCache.has(fileCacheKey)) {
            const entry = parseCache.get(fileCacheKey);
            if (entry.content === options.content) {
                return entry.parsedFile;
            }
        }
        parsedFile = (0, ResxReader_1.readResxAsLocFile)(options.content, {
            terminal: options.terminal,
            resxFilePath: options.filePath,
            newlineNormalization: options.resxNewlineNormalization,
            warnOnMissingComment: !options.ignoreMissingResxComments
        });
        parseCache.set(fileCacheKey, { content: options.content, parsedFile });
        return parsedFile;
    }
    else if (parser === 'loc.json') {
        return (0, parseLocJson_1.parseLocJson)(options);
    }
    else if (parser === 'resjson') {
        return (0, parseResJson_1.parseResJson)(options);
    }
    else {
        throw new Error(`Unsupported parser: ${parser}`);
    }
}
exports.parseLocFile = parseLocFile;
//# sourceMappingURL=LocFileParser.js.map